@@ -44,10 +44,13 @@ struct _GConfKeyEditor {
 	
 	int active_type;
 	GtkWidget *option_menu;
-	GtkWidget *notebook;
+	GtkWidget *bool_box;
 	GtkWidget *bool_widget;
+	GtkWidget *int_box;	
 	GtkWidget *int_widget;
+	GtkWidget *string_box;
 	GtkWidget *string_widget;
+	GtkWidget *float_box;
 	GtkWidget *float_widget;
 
 	GtkWidget *non_writable_label;
@@ -57,10 +60,11 @@ struct _GConfKeyEditor {
 	GtkWidget *name_entry;
 
 	/* List editing stuff */
+	GtkWidget *list_box;
 	GtkWidget *list_widget;
 	GtkListStore *list_model;
 	GtkWidget *list_type_menu;
-	GtkWidget *remove_button, *go_up_button, *go_down_button;
+	GtkWidget *edit_button, *remove_button, *go_up_button, *go_down_button;
 
 };
 
